@@ -92,7 +92,7 @@ PipeOpBoxCox = R6Class("PipeOpBoxCox",
       cols = colnames(dt)
       for (j in colnames(dt)) {
         set(dt, j = j,
-          value = predict(self$state$bc[[j]], newdata = dt[[j]]))
+          value = stats::predict(self$state$bc[[j]], newdata = dt[[j]]))
       }
       dt
     }
