@@ -74,33 +74,34 @@ PipeOpClassWeights = R6Class("PipeOpClassWeights",
         ParamDbl$new("minor_weight", lower = 0, upper = Inf, tags = "train")
       ))
       ps$values = list(minor_weight = 1)
-      super$initialize(id, param_set = ps, param_vals = param_vals, can_subset_cols = FALSE, task_type = "TaskClassif")
-    },
+      super$initialize(id, param_set = ps, param_vals = param_vals, can_subset_cols = FALSE, task_type = "TaskClassif", tags = "imbalanced data")
+    }
+  ),
+  private = list(
 
-    train_task = function(task) {
+    .train_task = function(task) {
 
-      if (length(levels(task$truth())) > 2) {
+      if ("twoclass" %nin% task$properties) {
         stop("Only binary classification Tasks are supported.")
       }
 
-      prior_weights = task$col_roles$weight
-      if (length(prior_weights)) {
-        task$set_col_role(prior_weights, character(0))
-      }
       weightcolname = ".WEIGHTS"
       if (weightcolname %in% unlist(task$col_roles)) {
-        stopf("Column '%s' is already in the Task and not a weight column; '.WEIGHTS' can therefore not be added.", weightcolname)
+        stopf("Weight column '%s' is already in the Task", weightcolname)
       }
 
       truth = task$truth()
       minor = names(which.min(table(task$truth())))
 
-      wcol = setNames(data.table(ifelse(truth == minor, self$param_set$values$minor_weight, 1)), weightcolname)
+      wcol = setnames(data.table(ifelse(truth == minor, self$param_set$values$minor_weight, 1)), weightcolname)
 
-      task$cbind(wcol)$set_col_role(weightcolname, "weight")
+      task$cbind(wcol)
+      task$col_roles$feature = setdiff(task$col_roles$feature, weightcolname)
+      task$col_roles$weight = weightcolname
+      task
     },
 
-    predict_task = identity
+    .predict_task = identity
   )
 )
 
