@@ -2,11 +2,11 @@
 #'
 #' @usage NULL
 #' @name mlr_pipeops_colapply
-#' @format [`R6Class`] object inheriting from [`PipeOpTaskPreproc`]/[`PipeOp`].
+#' @format [`R6Class`] object inheriting from [`PipeOpTaskPreprocSimple`]/[`PipeOpTaskPreproc`]/[`PipeOp`].
 #'
 #' @description
 #' Applies a function to each column of a task. Use the `affect_columns` parameter inherited from
-#' [`PipeOpTaskPreproc`] to limit the columns this function should be applied to. This can be used
+#' [`PipeOpTaskPreprocSimple`] to limit the columns this function should be applied to. This can be used
 #' for simple parameter transformations or type conversions (e.g. `as.numeric`).
 #'
 #' The same function is applied during training and prediction. One important relationship for
@@ -26,36 +26,30 @@
 #'   List of hyperparameter settings, overwriting the hyperparameter settings that would otherwise be set during construction. Default `list()`.
 #'
 #' @section Input and Output Channels:
-#' Input and output channels are inherited from [`PipeOpTaskPreproc`].
+#' Input and output channels are inherited from [`PipeOpTaskPreprocSimple`].
 #'
 #' The output is the input [`Task`][mlr3::Task] with features changed according to the `applicator` parameter.
 #'
 #' @section State:
-#' The `$state` is a named `list` with the `$state` elements inherited from [`PipeOpTaskPreproc`], as well as:
-#' * `emptydt` :: [`data.table`]\cr
-#'   An empty [`data.table`] with columns of names and types from *output* features after training. This is used
-#'   to produce a correct type conversion during prediction, even when the input has zero length and
-#'   `applicator` is therefore not called.
+#' The `$state` is a named `list` with the `$state` elements inherited from [`PipeOpTaskPreprocSimple`].
 #'
 #' @section Parameters:
-#' The parameters are the parameters inherited from [`PipeOpTaskPreproc`], as well as:
+#' The parameters are the parameters inherited from [`PipeOpTaskPreprocSimple`], as well as:
 #' * `applicator` :: `function`\cr
-#'   Function to apply to each column of the task. The return value must have the
-#'   same length as the input, i.e. vectorize over the input. A typical example would be `as.numeric`.
-#'   Use [`Vectorize`][base::Vectorize] to create a vectorizing function from any function that
-#'   ordinarily only takes one element input.\cr
-#'   The `applicator` is not called during prediction if the input task has no rows; instead the
-#'   types of affected features are changed to the result types of the `applicator` call during training.
-#'   Initialized to the `identity()`-function.
+#'   Function to apply to each column of the task.
+#'   The return value should be a `vector` of the same length as the input, i.e., the function vectorizes over the input.
+#'   A typical example would be `as.numeric`.\cr
+#'   The return value can also be a `matrix`, `data.frame`, or [`data.table`].
+#'   In this case, the length of the input must match the number of returned rows.
+#'   The names of the resulting features of the output [`Task`][mlr3::Task] is based on the (column) name(s) of the return value of the applicator function,
+#'   prefixed with the original feature name separated by a dot (`.`).
+#'   Use [`Vectorize`][base::Vectorize] to create a vectorizing function from any function that ordinarily only takes one element input.\cr
 #'
 #' @section Internals:
-#' [`PipeOpColApply`] can not inherit from [`PipeOpTaskPreprocSimple`], because if `applicator` is given
-#' and the prediction data has 0 rows, then the resulting [`data.table`] does not know
-#' what the column types should be. Column type conformity between training and prediction is enforced
-#' by simply saving a copy of an empty [`data.table`] in the `$state$emptydt` slot.
+#' Calls [`map`][mlr3misc::map] on the data, using the value of `applicator` as `f.` and coerces the output via [`as.data.table`].
 #'
 #' @section Fields:
-#' Only fields inherited from [`PipeOpTaskPreproc`]/[`PipeOp`].
+#' Only fields inherited from [`PipeOpTaskPreprocSimple`]/[`PipeOpTaskPreproc`]/[`PipeOp`].
 #'
 #' @section Methods:
 #' Only methods inherited from [`PipeOpTaskPreprocSimple`]/[`PipeOpTaskPreproc`]/[`PipeOp`].
@@ -71,7 +65,7 @@
 #' poca$train(list(task))[[1]]  # types are converted
 #'
 #' # function that does not vectorize
-#' f = function(x) {
+#' f1 = function(x) {
 #'   # we could use `ifelse` here, but that is not the point
 #'   if (x > 1) {
 #'     "a"
@@ -79,14 +73,22 @@
 #'     "b"
 #'   }
 #' }
-#' poca$param_set$values$applicator = Vectorize(f)
+#' poca$param_set$values$applicator = Vectorize(f1)
 #' poca$train(list(task))[[1]]$data()
 #'
-#' # only affect Petal.* columns:
+#' # only affect Petal.* columns
 #' poca$param_set$values$affect_columns = selector_grep("^Petal")
 #' poca$train(list(task))[[1]]$data()
+#'
+#' # function returning multiple columns
+#' f2 = function(x) {
+#'   cbind(floor = floor(x), ceiling = ceiling(x))
+#' }
+#' poca$param_set$values$applicator = f2
+#' poca$param_set$values$affect_columns = selector_all()
+#' poca$train(list(task))[[1]]$data()
 PipeOpColApply = R6Class("PipeOpColApply",
-  inherit = PipeOpTaskPreproc,
+  inherit = PipeOpTaskPreprocSimple,
   public = list(
     initialize = function(id = "colapply", param_vals = list()) {
       ps = ParamSet$new(params = list(
@@ -98,23 +100,12 @@ PipeOpColApply = R6Class("PipeOpColApply",
   ),
   private = list(
 
-    .train_dt = function(dt, levels, target) {
-      dt = private$.transform_dt(dt, levels)
-      self$state = list(emptydt = dt[integer(0)])
-      dt
+    .get_state_dt = function(dt, levels, target) {
+      list()
     },
 
-    .predict_dt = function(dt, levels) {
-      dt = private$.transform_dt(dt, levels)
-      if (!nrow(dt)) {
-        dt = self$state$emptydt
-      }
-      dt
-    },
-
-    .transform_dt = function(task, task_levels) {
-      applicator = self$param_set$values$applicator
-      task[, names(task) := lapply(task, applicator)]
+    .transform_dt = function(dt, levels) {
+      as.data.table(map(dt, .f = self$param_set$values$applicator))
     }
   )
 )
