@@ -5,10 +5,11 @@
 #' @format [`R6Class`] object inheriting from [`PipeOpTaskPreprocSimple`]/[`PipeOpTaskPreproc`]/[`PipeOp`].
 #'
 #' @description
-#' Linearly transforms numeric data columns so they are between `lower` and `upper`.
-#' The formula for this is \eqn{x' = a + x * b},
-#' where \eqn{b} is \eqn{(upper - lower) / (max(x) - min(x))} and
-#' \eqn{a} is \eqn{-min(x) * b + lower}.
+#' Linearly transforms numeric data columns so they are between `lower`
+#' and `upper`. The formula for this is \eqn{x' = offset + x * scale},
+#' where \eqn{scale} is \eqn{(upper - lower) / (max(x) - min(x))} and
+#' \eqn{offset} is \eqn{-min(x) * scale + lower}. The same transformation is applied during training and
+#' prediction.
 #'
 #' @section Construction:
 #' ```
@@ -27,15 +28,15 @@
 #'
 #' @section State:
 #' The `$state` is a named `list` with the `$state` elements inherited from [`PipeOpTaskPreproc`],
-#' as well as the two transformation parameters \eqn{a} and \eqn{b} for each numeric
+#' as well as the two transformation parameters \eqn{scale} and \eqn{offset} for each numeric
 #' feature.
 #'
 #' @section Parameters:
 #' The parameters are the parameters inherited from [`PipeOpTaskPreproc`], as well as:
-#' * `lower`  :: `numeric(1)` \cr
-#'   Target value of smallest item of input data. Default is 0.
-#' * `upper` :: `numeric(1)` \cr
-#'   Target value of greatest item of input data. Default is 1.
+#' * `lower` :: `numeric(1)`\cr
+#'   Target value of smallest item of input data. Initialized to 0.
+#' * `upper` :: `numeric(1)`\cr
+#'   Target value of greatest item of input data. Initialized to 1.
 #'
 #' @section Methods:
 #' Only methods inherited from [`PipeOpTaskPreprocSimple`]/[`PipeOpTaskPreproc`]/[`PipeOp`].
@@ -58,30 +59,28 @@ PipeOpScaleRange = R6Class("PipeOpScaleRange",
   public = list(
     initialize = function(id = "scalerange", param_vals = list()) {
       ps = ParamSet$new(params = list(
-        ParamDbl$new("lower", tags = c("required", "train", "predict")),
-        ParamDbl$new("upper", tags = c("required", "train", "predict"))
+        ParamDbl$new("lower", tags = c("required", "train")),
+        ParamDbl$new("upper", tags = c("required", "train"))
       ))
       ps$values = list(lower = 0, upper = 1)
-      super$initialize(id, param_set = ps, param_vals = param_vals)
-    },
+      super$initialize(id, param_set = ps, param_vals = param_vals, feature_types = c("numeric", "integer"))
+    }
+  ),
+  private = list(
 
-    select_cols = function(task) {
-      task$feature_types[get("type") %in% c("numeric", "integer"), get("id")]
-    },
-
-    get_state_dt = function(dt, levels, target) {
+    .get_state_dt = function(dt, levels, target) {
       lapply(dt, function(x) {
         rng = range(x, na.rm = TRUE, finite = TRUE)
-        b = (self$param_set$values$upper - self$param_set$values$lower) / (rng[2] - rng[1])
-        a = -rng[1] * b + self$param_set$values$lower
-        c(a, b)
+        scale = (self$param_set$values$upper - self$param_set$values$lower) / diff(rng)
+        offset = -rng[1L] * scale + self$param_set$values$lower
+        c(scale = scale, offset = offset)
       })
     },
 
-    transform_dt = function(dt, levels) {
+    .transform_dt = function(dt, levels) {
       for (i in seq_along(dt)) {
         trafo = self$state[[i]]
-        dt[[i]] = trafo[1] + dt[[i]] * trafo[2]
+        dt[[i]] = trafo[["offset"]] + dt[[i]] * trafo[["scale"]]
       }
       dt
     }
