@@ -1,3 +1,8 @@
+format_bib = function(...) {
+  str = vapply(list(...), function(entry) tools::toRd(bibentries[[entry]]), FUN.VALUE = "")
+  paste0(str, collapse = "\n\n")
+}
+
 #' @importFrom utils bibentry
 bibentries = c(
   chawla_2002 = bibentry("article",
