@@ -8,9 +8,9 @@ test_that("PipeOpImpute", {
     public = list(
       initialize = function(id = "impute", param_vals = list()) {
         ps = ParamSet$new(list(
-          ParamFct$new("method_num", levels = c("median", "mean", "mode", "sample", "hist", "oor", "constant"), default = "median", tags = c("train", "predict")),
-          ParamFct$new("method_fct", levels = c("oor", "sample", "mode", "constant"), default = "oor", tags = c("train", "predict")),
-          ParamFct$new("add_dummy", levels = c("none", "missing_train", "all"), default = "missing_train", tags = c("train", "predict")),
+          ParamFct$new("method_num", levels = c("median", "mean", "mode", "sample", "hist", "oor", "constant"), tags = c("train", "predict")),
+          ParamFct$new("method_fct", levels = c("oor", "sample", "mode", "constant"), tags = c("train", "predict")),
+          ParamFct$new("add_dummy", levels = c("none", "missing_train", "all"), tags = c("train", "predict")),
           ParamUty$new("innum", tags = c("train", "predict"))
         ))
         ps$values = list(method_num = "median", method_fct = "oor", add_dummy = "missing_train")
